#
# spec file for package lightsoff
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lightsoff
Version:        40.0.1
Release:        2.5
Summary:        Lights Out Game for GNOME
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Other
URL:            https://wiki.gnome.org/Apps/Lightsoff
Source0:        https://download.gnome.org/sources/lightsoff/40/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.22.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0
Obsoletes:      %{name}-doc <= 3.28.0

%description
Lights Out is a board game where the goal is to switch off all tiles.
Toggling the status of one tile, will also toggle the status of its
adjacent tiles.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.gnome.LightsOff.desktop
%{_datadir}/dbus-1/services/org.gnome.LightsOff.service
%{_datadir}/glib-2.0/schemas/org.gnome.LightsOff.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.LightsOff*
%{_datadir}/metainfo/org.gnome.LightsOff.appdata.xml
%{_mandir}/man6/lightsoff.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Fri Feb 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused nor needed pkgconfig(clutter-1.0) and
  pkgconfig(clutter-gtk-1.0) BuildRequires.
* Mon Mar 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0.1:
  + Updated appdata with 40.0 stable info.
- Changes from version 40.0:
  + Use unowned for GtkChild fields.
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Updated translations.
* Tue Feb  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + Rework UI to work better on smaller screens.
  + Updated translations.
* Tue Jan 12 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Code cleanup and modernization.
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Switch to GTK mode by default.
  + Updated translations.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated help.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Updated help.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Wed Sep  4 2019 dimstar@opensuse.org
- Update to version 3.33.92:
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated translations.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Snap build fixes.
  + Updated translations.
* Sat Feb 16 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Snap build fixes.
  + Unify application identifier.
  + Added tests to validate appdata and desktop.
  + Updated appdata.
  + Added flatpak nightly builds.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Reduced border and minimum size to fit Librem5.
  + Code cleanup.
  + Updated translations.
- Changes from version 3.31.1:
  + Removed appmenu.
  + Updated translations.
* Sun Sep 16 2018 badshah400@gmail.com
- Update to version 3.30.0:
  + Updated translations.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Added experimental clutter-less mode.
  + Updated translations.
* Tue Jun 19 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + Drop autotools, port to meson.
  + Update bugzilla references to gitlab.
  + Updated translations.
- Add meson BuildRequires and corresponding macros following
  upstreams port to meson buildsystem.
- Use autosetup macro.
- Drop hicolor-icon-theme BuildRequires: No longer needed, nor
  used.
- Add explicit pkgconfig(gmodule-2.0) and pkgconfig(gio-2.0)
  BuildRequires: meson checks for them.
* Thu Mar 15 2018 luc14n0@linuxmail.org
- Fix some dangling symlinks in lang subpackage if doc subpackage
  is not installed: revert doc subpackage split and obsolete it and
  package it into the main package instead.
* Tue Mar 13 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Fixed appdata installation.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb  5 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Added snap packaging.
  + Updated translations.
* Tue Nov 14 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Gettext migration.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/Lightsoff: current
  Lights Off's web page.
- Replace intltool by gettext BuildRequires: following upstream
  migration as shown above.
- Add fdupes BuildRequires and its macro for removal of duplicates
  under the data directory.
- Split package into a -doc subpackage: more than half the size of
  the package is documentation.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
- Drop obsolete post(un) handling and
  glib2_gsettings_schema_requires and following macros have been
  removed, glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un).
- Drop suse_update_desktop_file macro, no longer needed as this
  happens automatically.
* Tue Aug 15 2017 dimstar@opensuse.org
- Update to version 3.25.90:
  + Fixed submit bug button text in help.
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + Updated translations.
* Fri Nov 11 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Added content ratings.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Updated translations.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Updated appdata.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Stable release version bump.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Updated AppData to spec 0.7.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Stop using deprecated gnome-common.
  + Add pre-commit and pre-applypatch hooks.
  + Updated translations.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Updated appdata and doap.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Sep 15 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Updated translations.
* Tue Apr 28 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Updated moves' counter on keyboard move.
  + Use GResource for loading the app-menu.
  + Use GtkBuilder.
  + Provide symbolic variant of app icon.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1.1:
  + Fix installation of hicolor icon.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Update moved counter when using keyboard.
  + Provide a symbolic icon
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Updated about dialog.
  + Renamed New Game to Start Over.
  + Updated translations.
* Mon Jan 26 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Implemented moves counter.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Switch to appstream util validate from appdata validation.
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Appdata: updated screenshot size.
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Removed level changer LED in favor of proper buttons.
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Fixed touch screen handling for arrows.
  + Updated translations.
- Add pkgconfig(librsvg-2.0) BuildRequires: new dependency.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Updated documentations.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Fixed touch screen issue where taping didnt work.
  + Bump clutter dep to 1.14.0, clutter-gtk to 1.4.0.
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + appdata: specify project_group.
* Mon Feb  3 2014 zaitor@opensuse.org
- Update to version 3.11.5:
  + Updated translations.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Update website in about dialog.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + About dialog: use GtkLicense.
  + Appdata: update homepage.
  + App menu: standardize Help/About/Quit.
  + Use a GtkHeaderBar.
  + Depend on GTK+ 3.10, Vala 0.22.
  + Use dark theme.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Fix compilation in Fedora 19.
  + Drop fixes.vapi.
  + appdata: adjust screenshot size.
  + Check for *-validate before using them, run autoupdate.
  + Updated translations.
* Tue Oct 29 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Validate appdata and desktop file at make check, etc.
  + Remove .desktop.in.in and BugBuddy info.
  + Rely on intltool >=0.50 for gsettings translation.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Make the window unresizable.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add appdata file.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix some broken links in user help.
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
- Changes from version 3.7.92:
  + Added high contrast icon.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
